@@ -1,6 +1,7 @@
-CAP<-function(x, transform=NULL) {
-  cap<-function(x) {
-    y = as.data.frame(x)
+CAP<-function(x, transform=NULL, verbose=FALSE) {
+  cap<-function(x, verbose=FALSE) {
+    if(verbose) cat(".")
+    y = as.matrix(x)
     if(ncol(y)>1) {
       for(i in (ncol(y)-1):1) {
         y[,i] = y[,i]+y[,i+1]
@@ -9,8 +10,9 @@ CAP<-function(x, transform=NULL) {
     return(y)
   }
   if(!inherits(x,"stratifiedvegdata")) stop("Input should be of class 'stratifiedvegdata'")
-  Y = lapply(x, FUN=cap)
+  Y = lapply(x, FUN=cap, verbose=verbose)
   if(!is.null(transform)) Y = lapply(Y, FUN=transform)
-  class(Y)<-c("list","CAP")
+  names(Y)<-names(x)
+  class(Y)<-c("CAP","list")
   return(Y)
 }
\ No newline at end of file
