@@ -1,7 +1,5 @@
-plot.CAP<-function(x, sizes=NULL, species=NULL, plots=NULL, switchAxes=FALSE, add=FALSE, xlab="", ylab="",...) {
-  if(!is.null(plots)) {
-    x = x[names(x) %in% plots]
-  }
+plot.CAP<-function(x, sizes=NULL, species=NULL, plots=NULL, switchAxes=FALSE, add=FALSE, drawAxes=TRUE, xlab="", ylab="", type="s",...) {
+  if(!is.null(plots)) x = x[plots]
   if(length(x)==0) stop("No site samples to draw. Check your selection.")
   spnames = row.names(as.data.frame(x[[1]]))
   if(length(spnames)==0) stop("No species to draw. Check your selection.")
@@ -21,14 +19,16 @@ plot.CAP<-function(x, sizes=NULL, species=NULL, plots=NULL, switchAxes=FALSE, ad
       plot(x=c(0,sizes), y=as.numeric(c(0,rep(maxval, length(sizes)))),
               type="n", axes=FALSE,xlab = xlab, ylab=ylab,...)
     }
-    axis(1,pos=0)
-    axis(2,pos=0)
+    if(drawAxes) {
+      axis(1,pos=0)
+      axis(2,pos=0)
+    }
   }
   for(i in 1:length(x)) {
     cap = x[[i]]
-    cap  = cap[row.names(cap) %in% spnames,]
-    cap = cbind(cap[,1],cap)
-    if(switchAxes) matlines(x=t(cap), y=c(0,sizes), type="s",...)
-    else matlines(x=c(0,sizes), y=t(cap), type="s",...)
+    cap  = cap[rownames(cap) %in% spnames,, drop=FALSE]
+    cap = cbind(cap,0)
+    if(switchAxes) matlines(x=t(cap), y=c(0,sizes), type=type,...)
+    else matlines(x=c(0,sizes), y=t(cap), type=type,...)
   }
 }
\ No newline at end of file
